# MoleculeKit

[![Build Status](https://dev.azure.com/stefdoerr/moleculekit/_apis/build/status/Acellera.moleculekit?branchName=master)](https://dev.azure.com/stefdoerr/moleculekit/_build/latest?definitionId=1&branchName=master)
[![Build Status](https://travis-ci.org/Acellera/moleculekit.svg?branch=master)](https://travis-ci.org/Acellera/moleculekit)
[![Language Grade: Python](https://img.shields.io/lgtm/grade/python/g/Acellera/moleculekit.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Acellera/moleculekit/context:python) 
[![Conda](https://anaconda.org/acellera/moleculekit/badges/version.svg)](https://anaconda.org/acellera/moleculekit)
[![codecov](https://codecov.io/gh/Acellera/moleculekit/branch/master/graph/badge.svg)](https://codecov.io/gh/Acellera/moleculekit)

Molecule manipulation library